@@ -5,27 +5,27 @@
     <name>MainWindow</name>
     <message>
         <source>Selected theme is currently in use!</source>
-        <translation type="unfinished"></translation>
+        <translation>选定的主题是目前正在使用!</translation>
     </message>
     <message>
         <source>You can&apos;t delete a theme that&apos;s currently active.</source>
-        <translation type="unfinished"></translation>
+        <translation>无法删除当前活动的主题.</translation>
     </message>
     <message>
         <source>Delete saved themes</source>
-        <translation type="unfinished"></translation>
+        <translation>删除保存的主题</translation>
     </message>
     <message>
         <source>Delete theme?</source>
-        <translation type="unfinished"></translation>
+        <translation>删除主题?</translation>
     </message>
     <message>
         <source>Are you sure you want to delete this theme?</source>
-        <translation type="unfinished"></translation>
+        <translation>确定要删除这个主题吗?</translation>
     </message>
     <message>
         <source>Theme deleted.</source>
-        <translation type="unfinished"></translation>
+        <translation>主题删除.</translation>
     </message>
     <message>
         <source>+1</source>
@@ -444,15 +444,15 @@
     <name>managethemes</name>
     <message>
         <source>Select theme:</source>
-        <translation type="unfinished"></translation>
+        <translation>选择主题:</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>删除</translation>
     </message>
     <message>
         <source>No themes created by Theme Customizer found</source>
-        <translation type="unfinished"></translation>
+        <translation>没有找到被创建的主题</translation>
     </message>
 </context>
 </TS>
